(function ($, server, host, player) {
    
    var gui = {};

    gui.showIntroScreen = function(roleSelectedCallback) {
        $.mobile.pageContainer.pagecontainer('change', '#intro-page', { transition: 'slide', changeHash: false });

        $('#create-btn').one('click', function() {
            roleSelectedCallback('host');
        });

        $('#join-btn').one('click', function() {
            roleSelectedCallback('player');
        });
    };

    gui.showSelectGameModeScreen = function(gameModeSelectedCallback) {
        $.mobile.pageContainer.pagecontainer('change', '#select-gamemode-page', { transition: 'slide', changeHash: false });

        $('#completness-btn').one('click', function(){
            gameModeSelectedCallback('completeness');
        });

        $('#reaction-btn').one('click', function(){
            gameModeSelectedCallback('reaction');
        });
    };

    gui.showStartGameScreen = function(gameId, startGameButtonClickedCallback) {
        $.mobile.pageContainer.pagecontainer('change', '#start-game-page', { transition: 'slide', changeHash: false });

        $('#game-url').text(window.location.href);
        $('#game-id').text(gameId);

        $('#host-start-btn').one('click', function() {
            startGameButtonClickedCallback();
        });
    };

    gui.showJoinGameScreen = function(joinGameButtonClickedCallback) {
        $.mobile.pageContainer.pagecontainer('change', '#join-game-page', { transition: 'slide', changeHash: false });

        $('#join-start-btn').one('click', function() {
            joinGameButtonClickedCallback($('#gameid-input').val(), $('#playername-input').val() || 'Anonymous');
            $('#join-start-btn').attr('disabled', true);
            $('#join-start-btn').html('Waiting for game to start');
        });
    };

    gui.showCountdownScreen = function(seconds) {
        $.mobile.pageContainer.pagecontainer('change', '#countdown-page', { transition: 'slide', changeHash: false });

        $('.countdown').ClassyCountdown({
            theme: "flat-colors-very-wide",
            end: $.now() + seconds
        });
    };

    gui.showHostQuestionScreen = function(questionIndex, questionText, seconds) {
        $.mobile.pageContainer.pagecontainer('change', '#host-question-page', { transition: 'slide', changeHash: false });

        $('#question-header').text("Question " + (questionIndex + 1));
        $('#question-bar').text("QUESTION " + (questionIndex + 1));
        $('#question-text').text(questionText);
        
        $('.countdown').ClassyCountdown({
            theme: "flat-colors-very-wide",
            end: $.now() + seconds
        });
    };

    gui.showPlayerQuestionScreen = function(options, gameMode, selectionChangedCallback) {
        $.mobile.pageContainer.pagecontainer('change', '#player-question-page', { transition: 'slide', changeHash: false });

        $('#options-field').controlgroup('container').empty();
        $.each(options, function() {
            var checkbox = '<input type="checkbox" name="' + this + '" id="' + this +'"value="' + this + '"><label for="' + this + '">' + this + '</label>';
            $('#options-field').controlgroup('container').append(checkbox);
        });

        $('#options-field').enhanceWithin().controlgroup('refresh');


        $('input[type="checkbox"]').each(function() {
            $(this).click(function() {

                var answers = [];
                $('input:checkbox:checked').each(function() {
                    answers.push($(this).val());
                });

                if (gameMode == 'reaction') {
                    $("input[type='checkbox']").checkboxradio('disable');
                }

                selectionChangedCallback(answers);
            });
        });
    };

    gui.showHostEndQuestionScreen = function(scores, answers, nextQuestionButtonClickedCallback) {
        $.mobile.pageContainer.pagecontainer('change', '#host-end-question-page', { transition: 'slide', changeHash: false });

        $('#score-table tbody').empty();

        populateScoreTable(scores, 10, '#score-table');

        $('#next-question-btn').one('click', function(){
            nextQuestionButtonClickedCallback();
        });

        console.log(answers);

        $('#solution-list').empty().append('<li data-role="list-divider">Solution</li>');
        $.each(answers, function() {
            $('#solution-list').append('<li>' + this + '</li>');
        })
        $('#solution-list').listview("refresh").enhanceWithin();
        
    };

    gui.showPlayerEndQuestionScreen = function(scores, playerId) {

        $.mobile.pageContainer.pagecontainer('change', '#player-end-question-page', { transition: 'slide', changeHash: false });

        var playerPosition = -1;

        for (var i = 0; i < scores.length; i++) {
            if (scores[i].playerId === playerId) {
                playerPosition = i;
                break;
            }
        }

        $('#position-table tbody').empty();
        var row = '';

        row += '<tr id="player-position"><td>' + (playerPosition+1) + '</td><td>' + scores[playerPosition].playerName + '</td><td>' + scores[playerPosition].score + '</td></tr>';

        $('#position-table tbody').append(row);
        $('#position-table').table('refresh').enhanceWithin();
    };

    gui.showGameEndScreen = function(scores) {
        $.mobile.pageContainer.pagecontainer('change', '#game-end-page', { transition: 'slide', changeHash: false });

        populateScoreTable(scores, 3, '#final-score-table');
    };

    function populateScoreTable(scores, stopRank, table) {
        var rank = 1;

        $.each(scores.slice(0, stopRank), function(){
            var row = "<tr><td>" + rank + "</td><td>" + this.playerName + "</td><td>" + this.score + "</td></tr>";
            $(table + ' tbody').append(row);
            rank++;
        });

        $(table).table('refresh').enhanceWithin();
    }

    function doTextFit(element) {
        textFit(element, {
            alignHoriz:true,
            alignVert:true,
            widthOnly:false,
            reProcess:true,
            maxFontSize:300
        });
    }

    server.init(function() {

        gui.showIntroScreen(function(role){
            if(role == 'host'){
                host.init(gui);
            }else if(role == 'player'){
                player.init(gui);
            }
        });
    });

}($, quizServer, quizHost, quizPlayer));