var quizServer = (function () {
    
    var server = {};
    server.callbacks = {}

    server.init = function(callback) {
        server.socket = io.connect();
        server.callbacks.connected = callback;

        server.socket.on('connected', server.connected);
        server.socket.on('error', server.error);

        server.socket.on('gameCreated', server.gameCreated);
        server.socket.on('prepareQuestion', server.prepareQuestion);
        server.socket.on('nextQuestion', server.nextQuestion);
        server.socket.on('questionEnded', server.questionEnded);
        server.socket.on('gameEnded', server.gameEnded);

        server.connected();
    };

    server.createGame = function(gameMode, gameCreatedCallback, gameEndedCallback) {
        server.socket.emit('createGame',{gameMode: gameMode});

        server.callbacks.gameCreated = gameCreatedCallback;
        server.callbacks.gameEnded = gameEndedCallback;
    };

    server.joinGame = function(gameId, playerName, gameJoinedCallback,  prepareCallback, nextQuestionCallback, questionEndedCallback, gameEndedCallback) {
        var playerId = server.socket.io.engine.id;
        server.socket.emit('joinGame',{
            gameId: gameId,
            playerId: playerId,
            playerName: playerName
        });

        server.callbacks.prepareQuestion = prepareCallback;
        server.callbacks.nextQuestion = nextQuestionCallback;
        server.callbacks.questionEnded = questionEndedCallback;
        server.callbacks.gameEnded = gameEndedCallback;

        gameJoinedCallback(playerId);
    };

    server.prepareNextQuestion = function(gameId, prepareCallback, nextQuestionCallback, questionEndedCallback) {
        server.socket.emit('nextQuestion', {gameId: gameId});

        server.callbacks.prepareQuestion = prepareCallback;
        server.callbacks.nextQuestion = nextQuestionCallback;
        server.callbacks.questionEnded = questionEndedCallback;
    };

    server.submitAnswer = function(gameId, playerId, questionIndex, answers) {
        server.socket.emit('submitAnswer',{
            gameId: gameId,
            playerId: playerId,
            questionIndex: questionIndex,
            answers: answers
        });
    };

    server.connected = function() {
        server.callbacks.connected();
    };

    server.error = function(data) {
        alert(data);
    };

    server.gameCreated = function(data) {
        server.callbacks.gameCreated(data['gameId']);
    };

    server.prepareQuestion = function(data) {
        server.callbacks.prepareQuestion(data['time']);
    };

    server.nextQuestion = function(data) {
        server.callbacks.nextQuestion(data['index'], data['text'], data['time'], data['options'], data['gameMode']);
    };
    
    server.questionEnded = function(data) {
        server.callbacks.questionEnded(data['scores'], data['answers']);
    };

    server.gameEnded = function(data) {
        server.callbacks.gameEnded(data['scores']);
    };

    return server;
}());